@@ -1,9 +1,9 @@
 /*
- * install.h
+ * include/install.h
  * 
  * include file for install.c
  *
- * Copyright (c) Tuomo Valkonen 1996-1997.
+ * Copyright (c) Tuomo Valkonen 1996-1998.
  */
 #ifndef INSTALL_H
 #define INSTALL_H
@@ -19,6 +19,7 @@ typedef struct geom{
  
 int get_device(int fdp,GEOMETRY *geo);
 int open_dev(dev_t device );
+void do_add_biosdrive_map(char*str);
 int verify_bios_read(GEOMETRY *geo,ulong addr);
 int install_it(void);
 int get_addr(int fd, int sect, GEOMETRY *geo);
